@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 
 from ConfigParser import SafeConfigParser
+from logging import getLogger
 from os.path import abspath, dirname, join, sep, split, splitext
 from re import match, sub
 from weakref import proxy
 from werkzeug.local import LocalProxy
 
-from util import smart_coerce
+from util import convert
+
+logger = getLogger('project')
 
 class ProjectImportError(Exception):
 
@@ -29,6 +32,8 @@ class Project(object):
 
   __current__ = None
 
+  _managers = None
+
   config = {
     'PROJECT': {
       'NAME': '',
@@ -39,11 +44,9 @@ class Project(object):
       'APP_FOLDER': 'app',
       'APP_STATIC_FOLDER': 'static',
       'APP_TEMPLATE_FOLDER': 'templates',
-      'OAUTH_CLIENT': '',
-      'AUTHORIZED_EMAILS': '',
     },
     'APP': {
-      'SECRET_KEY': '',
+      'SECRET_KEY': 'a_default_unsafe_key',
     },
     'CELERY': {
       'BROKER_URL': 'redis://',
@@ -53,10 +56,15 @@ class Project(object):
   }
 
   def __init__(self, config_path):
+
     config = self.parse_config(config_path)
     for key in config:
-      self.config[key].update(config[key])
+      if key in self.config:
+        self.config[key].update(config[key])
+      else:
+        self.config[key] = config[key]
     self.check_config()
+
     self.root_dir = dirname(abspath(config_path))
     self.domain = (
       self.config['PROJECT']['DOMAIN'] or
@@ -66,10 +74,10 @@ class Project(object):
       self.config['PROJECT']['SUBDOMAIN'] or
       splitext(config_path)[0].replace(sep, '-')
     )
-    # create current_project proxy
+
     assert Project.__current__ is None, 'More than one project.'
     Project.__current__ = proxy(self)
-    # project components, 3 as of right now
+
     self.app = None
     self.celery = None
     self.db = None
@@ -94,7 +102,7 @@ class Project(object):
         'Unable to parse configuration file at %s.' % config_path
       )
     return dict(
-      (s, dict((k, smart_coerce(v)) for (k, v) in parser.items(s)))
+      (s, dict((k, convert(v)) for (k, v) in parser.items(s)))
       for s in parser.sections()
     )
 
@@ -109,19 +117,37 @@ class Project(object):
     if not conf['PROJECT']['NAME']:
       raise ProjectImportError('Missing project name.')
 
+  def setup_logger(self):
+    """Setup the project logger.
+    
+    TODO.
+    
+    """
+    pass
+
   def make(self):
     """Create all project components.
 
     Note that the database connection isn't created here.
     
     """
-    components = ['app', 'database', 'celery']
-    map(__import__, ('flasker.components.%s' % c for c in components))
-    if self.config['PROJECT']['MODULES']:
-      map(
-        __import__,
-        [mod.strip() for mod in self.config['PROJECT']['MODULES'].split(',')]
-      )
+    for mod in  ['app', 'database', 'celery']:
+      __import__('flasker.core.%s' % mod)
+    project_modules = self.config['PROJECT']['MODULES'].split(',') or []
+    for mod in project_modules:
+      __import__(mod.strip())
+    for manager, config_section in self._managers:
+      if config_section:
+        for k, v in self.config[config_section].items():
+          manager.config[k] = v
+      manager._before_register(self)
+      self.app.register_blueprint(manager.blueprint)
+      manager._after_register(self)
+
+  def register_manager(self, manager, config_section=None):
+    """Register a manager."""
+    self._managers = self._managers or []
+    self._managers.append((manager, config_section))
 
   @classmethod
   def get_current_project(cls):
